@@ -1,7 +1,5 @@
-from __future__ import annotations
-
 from dataclasses import dataclass, field
-from enum import Enum, auto
+from email.policy import default
 from pathlib import Path
 from typing import (
     Any,
@@ -9,7 +7,6 @@ from typing import (
     Dict,
     Iterator,
     List,
-    Literal,
     Optional,
     Sequence,
     Set,
@@ -17,33 +14,10 @@ from typing import (
     Union,
 )
 
-try:
-    from numpy.typing import NDArray
-except ImportError:
-    NDArray = Any  # type:ignore
-
-from darwin.future.data_objects.properties import PropertyType, SelectedProperty
-from darwin.path_utils import construct_full_path, is_properties_enabled, parse_metadata
-
-# Utility types
-
-NumberLike = Union[
-    int, float
-]  # Used for functions that can take either an int or a float
-# Used for functions that _genuinely_ don't know what type they're dealing with, such as those that test if something is of a certain type.
-UnknownType = Any  # type:ignore
-
-# Specific types
-
-ErrorList = List[Exception]
-
-
-class Success(Enum):
-    SUCCESS = auto()
-    FAILURE = auto()
-    PARTIAL_SUCCESS = auto()
-    UNDETERMINED = auto()
+from darwin.path_utils import construct_full_path
 
+UnknownType = Any  # type: ignore
+NumberLike = Union[int, float]
 
 Point = Dict[str, float]
 BoundingBox = Dict[str, float]
@@ -60,11 +34,7 @@ PathLike = Union[str, Path]
 ErrorHandler = Callable[[int, str], None]
 
 ItemId = Union[str, int]
-
-# Types that assist in handling JSON payloads
-JSONFreeForm = Dict[str, UnknownType]
-DictFreeForm = JSONFreeForm
-KeyValuePairDict = Dict[str, UnknownType]
+JSONFreeForm = Dict[str, Any]  # type: ignore
 
 
 class JSONType:
@@ -83,23 +53,13 @@ class JSONType:
         return cls(**json)
 
 
-AnnotationType = Literal[  # NB: Some of these are not supported yet
-    "bounding_box",
-    "polygon",
-    "complex_polygon",
-    "ellipse",
-    "cuboid",
-    "segmentation",
-    "raster_layer",
-    "mask",
-    "keypoint",
-    "tag",
-    "line",
-    "skeleton",
-    "table",
-    "string",
-    "graph",
-]
+class DictFreeForm:
+    def __init__(self, **kwargs: JSONFreeForm):
+        self.__dict__.update(kwargs)
+
+    @classmethod
+    def from_dict(cls, json: JSONFreeForm) -> "DictFreeForm":
+        return cls(**json)
 
 
 @dataclass
@@ -148,7 +108,7 @@ class AnnotationClass:
     name: str
 
     #: The type of this ``AnnotationClass``.
-    annotation_type: AnnotationType
+    annotation_type: str
 
     #: The V7 internal type of this ``AnnotationClass``.
     #: This is mostly used to convert from types that are known in the outside world by a given
@@ -170,11 +130,6 @@ class SubAnnotation:
     data: UnknownType
 
 
-class AnnotationAuthorRole(Enum):
-    ANNOTATOR = "annotator"
-    REVIEWER = "reviewer"
-
-
 @dataclass(frozen=True, eq=True)
 class AnnotationAuthor:
     """
@@ -213,12 +168,6 @@ class Annotation:
     #: Authorship of the annotation (reviewers)
     reviewers: Optional[List[AnnotationAuthor]] = None
 
-    # The darwin ID of this annotation.
-    id: Optional[str] = None
-
-    # Properties of this annotation.
-    properties: Optional[list[SelectedProperty]] = None
-
     def get_sub(self, annotation_type: str) -> Optional[SubAnnotation]:
         """
         Returns the first SubAnnotation that matches the given type.
@@ -270,18 +219,10 @@ class VideoAnnotation:
     #: Authorship of the annotation (reviewers)
     reviewers: Optional[List[AnnotationAuthor]] = None
 
-    # The darwin ID of this annotation.
-    id: Optional[str] = None
-
-    # Properties of this annotation.
-    properties: Optional[list[SelectedProperty]] = None
-
     def get_data(
         self,
         only_keyframes: bool = True,
-        post_processing: Optional[
-            Callable[[Annotation, UnknownType], UnknownType]
-        ] = None,
+        post_processing: Optional[Callable[[Annotation, UnknownType], UnknownType]] = None,
     ) -> Dict:
         """
         Return the post-processed frames and the additional information from this
@@ -315,9 +256,7 @@ class VideoAnnotation:
         """
         if not post_processing:
 
-            def post_processing(
-                annotation: Annotation, data: UnknownType
-            ) -> UnknownType:
+            def post_processing(annotation: Annotation, data: UnknownType) -> UnknownType:
                 return data  # type: ignore
 
         output = {
@@ -339,9 +278,6 @@ class VideoAnnotation:
         return output
 
 
-AnnotationLike = Union[Annotation, VideoAnnotation]
-
-
 @dataclass
 class Slot:
     #: Unique slot name in the item. Will be `None` when loading V1 exports.
@@ -374,12 +310,6 @@ class Slot:
     #: Metadata of the slot
     metadata: Optional[Dict[str, UnknownType]] = None
 
-    #: Frame Manifest for video slots
-    frame_manifest: Optional[List[Dict[str, UnknownType]]] = None
-
-    #: Segments for video slots
-    segments: Optional[List[Dict[str, UnknownType]]] = None
-
 
 @dataclass
 class AnnotationFileVersion:
@@ -395,99 +325,6 @@ class AnnotationFileVersion:
         return f"{self.major}.{self.minor}{self.suffix}"
 
 
-@dataclass
-class Property:
-    """
-    Represents a property of an annotation file.
-    """
-
-    # Name of the property
-    name: str
-
-    # Type of the property
-    type: PropertyType
-
-    # Whether the property is required or not
-    required: bool
-
-    # Property options
-    property_values: list[dict[str, Any]]
-
-    # Description of the property
-    description: Optional[str] = None
-
-
-@dataclass
-class PropertyClass:
-    name: str
-    type: str
-    description: Optional[str]
-    color: Optional[str] = None
-    sub_types: Optional[list[str]] = None
-    properties: Optional[list[Property]] = None
-
-
-def parse_property_classes(metadata: dict[str, Any]) -> list[PropertyClass]:
-    """
-    Parses the metadata file and returns a list of PropertyClass objects.
-
-    Parameters
-    ----------
-    metadata : dict[str, Any]
-        The metadata file.
-
-    Returns
-    -------
-    list[PropertyClass]
-        A list of PropertyClass objects.
-    """
-    assert "classes" in metadata, "Metadata does not contain classes"
-
-    classes = []
-    for metadata_cls in metadata["classes"]:
-        assert (
-            "properties" in metadata_cls
-        ), "Metadata class does not contain properties"
-        classes.append(
-            PropertyClass(
-                name=metadata_cls["name"],
-                type=metadata_cls["type"],
-                description=metadata_cls.get("description"),
-                color=metadata_cls.get("color"),
-                sub_types=metadata_cls.get("sub_types"),
-                properties=[Property(**p) for p in metadata_cls["properties"]],
-            )
-        )
-
-    return classes
-
-
-def split_paths_by_metadata(
-    path, dir: str = ".v7", filename: str = "metadata.json"
-) -> tuple[Path, Optional[list[PropertyClass]]]:
-    """
-    Splits the given path into two: the path to the metadata file and the path to the properties
-
-    Parameters
-    ----------
-    path : Path
-        The path to the export directory.
-
-    Returns
-    -------
-    tuple[Path, Optional[list[PropertyClass]]]
-        A tuple containing the path to the metadata file and the list of property classes.
-    """
-    metadata_path = is_properties_enabled(path, dir, filename)
-    if isinstance(metadata_path, bool):
-        return path, None
-
-    metadata = parse_metadata(metadata_path)
-    property_classes = parse_property_classes(metadata)
-
-    return metadata_path, property_classes
-
-
 @dataclass
 class AnnotationFile:
     """
@@ -551,12 +388,6 @@ class AnnotationFile:
     # e.g. (1, 0, 'a')
     version: AnnotationFileVersion = field(default_factory=AnnotationFileVersion)
 
-    # The darwin ID of the item that these annotations belong to.
-    item_id: Optional[str] = None
-
-    # The Frame Count if this is a video annotation
-    frame_count: Optional[int] = None
-
     @property
     def full_path(self) -> str:
         """
@@ -612,9 +443,7 @@ def make_bounding_box(
 
 
 def make_tag(
-    class_name: str,
-    subs: Optional[List[SubAnnotation]] = None,
-    slot_names: Optional[List[str]] = None,
+    class_name: str, subs: Optional[List[SubAnnotation]] = None, slot_names: Optional[List[str]] = None
 ) -> Annotation:
     """
     Creates and returns a tag annotation.
@@ -631,9 +460,7 @@ def make_tag(
     Annotation
         A tag ``Annotation``.
     """
-    return Annotation(
-        AnnotationClass(class_name, "tag"), {}, subs or [], slot_names=slot_names or []
-    )
+    return Annotation(AnnotationClass(class_name, "tag"), {}, subs or [], slot_names=slot_names or [])
 
 
 def make_polygon(
@@ -757,10 +584,7 @@ def make_keypoint(
         A point ``Annotation``.
     """
     return Annotation(
-        AnnotationClass(class_name, "keypoint"),
-        {"x": x, "y": y},
-        subs or [],
-        slot_names=slot_names or [],
+        AnnotationClass(class_name, "keypoint"), {"x": x, "y": y}, subs or [], slot_names=slot_names or []
     )
 
 
@@ -795,12 +619,7 @@ def make_line(
     Annotation
         A line ``Annotation``.
     """
-    return Annotation(
-        AnnotationClass(class_name, "line"),
-        {"path": path},
-        subs or [],
-        slot_names=slot_names or [],
-    )
+    return Annotation(AnnotationClass(class_name, "line"), {"path": path}, subs or [], slot_names=slot_names or [])
 
 
 def make_skeleton(
@@ -837,10 +656,7 @@ def make_skeleton(
         A skeleton ``Annotation``.
     """
     return Annotation(
-        AnnotationClass(class_name, "skeleton"),
-        {"nodes": nodes},
-        subs or [],
-        slot_names=slot_names or [],
+        AnnotationClass(class_name, "skeleton"), {"nodes": nodes}, subs or [], slot_names=slot_names or []
     )
 
 
@@ -889,12 +705,7 @@ def make_ellipse(
     Annotation
         An ellipse ``Annotation``.
     """
-    return Annotation(
-        AnnotationClass(class_name, "ellipse"),
-        parameters,
-        subs or [],
-        slot_names=slot_names or [],
-    )
+    return Annotation(AnnotationClass(class_name, "ellipse"), parameters, subs or [], slot_names=slot_names or [])
 
 
 def make_cuboid(
@@ -934,12 +745,7 @@ def make_cuboid(
     Annotation
         A cuboid ``Annotation``.
     """
-    return Annotation(
-        AnnotationClass(class_name, "cuboid"),
-        cuboid,
-        subs or [],
-        slot_names=slot_names or [],
-    )
+    return Annotation(AnnotationClass(class_name, "cuboid"), cuboid, subs or [], slot_names=slot_names or [])
 
 
 def make_table(
@@ -1037,10 +843,7 @@ def make_string(
         A string ``Annotation``.
     """
     return Annotation(
-        AnnotationClass(class_name, "string"),
-        {"sources": sources},
-        subs or [],
-        slot_names=slot_names or [],
+        AnnotationClass(class_name, "string"), {"sources": sources}, subs or [], slot_names=slot_names or []
     )
 
 
@@ -1094,91 +897,7 @@ def make_graph(
         A graph ``Annotation``.
     """
     return Annotation(
-        AnnotationClass(class_name, "graph"),
-        {"nodes": nodes, "edges": edges},
-        subs or [],
-        slot_names=slot_names or [],
-    )
-
-
-def make_mask(
-    class_name: str,
-    subs: Optional[List[SubAnnotation]] = None,
-    slot_names: Optional[List[str]] = None,
-) -> Annotation:
-    """
-    Creates and returns a mask annotation.
-
-    Parameters
-    ----------
-    class_name : str
-        The name of the class for this ``Annotation``.
-    subs : Optional[List[SubAnnotation]], default: None
-        List of ``SubAnnotation``s for this ``Annotation``.
-
-    Returns
-    -------
-    Annotation
-        A mask ``Annotation``.
-    """
-    return Annotation(
-        AnnotationClass(class_name, "mask"), {}, subs or [], slot_names=slot_names or []
-    )
-
-
-def make_raster_layer(
-    class_name: str,
-    mask_annotation_ids_mapping: Dict[str, str],
-    total_pixels: int,
-    dense_rle: List[int],
-    subs: Optional[List[SubAnnotation]] = None,
-    slot_names: Optional[List[str]] = None,
-) -> Annotation:
-    """
-    Creates and returns a raster_layer annotation.
-
-    Parameters
-    ----------
-    class_name : str
-        The name of the class for this ``Annotation``.
-
-    mask_annotation_ids_mapping : Dict[str, str]
-        Mapping of mask annotations ids to unique small integers used in the dense_rle.
-        Should be in following format:
-        .. code-block:: javascript
-
-            {
-                "91bb3c24-883a-433b-ae95-a6ee7845bea5": 1,
-                "5a0ceba1-2e26-425e-8579-e6013ca415c5": 2
-            }
-
-    total_pixels : int
-        Total number of pixels in a corresponding image.
-
-    dense_rle : int
-        Run length encoding of all masks in the raster layer.
-        Should be in following format:
-        .. code-block:: javascript
-
-            [0, 5, 1, 15, 2, 10]
-
-    subs : Optional[List[SubAnnotation]], default: None
-        List of ``SubAnnotation``\\s for this ``Annotation``.
-
-    Returns
-    -------
-    Annotation
-        A raster_layer ``Annotation``.
-    """
-    return Annotation(
-        AnnotationClass(class_name, "raster_layer"),
-        {
-            "mask_annotation_ids_mapping": mask_annotation_ids_mapping,
-            "total_pixels": total_pixels,
-            "dense_rle": dense_rle,
-        },
-        subs or [],
-        slot_names=slot_names or [],
+        AnnotationClass(class_name, "graph"), {"nodes": nodes, "edges": edges}, subs or [], slot_names=slot_names or []
     )
 
 
@@ -1282,7 +1001,6 @@ def make_video_annotation(
     segments: List[Segment],
     interpolated: bool,
     slot_names: List[str],
-    properties: Optional[list[SelectedProperty]] = None,
 ) -> VideoAnnotation:
     """
     Creates and returns a ``VideoAnnotation``.
@@ -1313,19 +1031,11 @@ def make_video_annotation(
         raise ValueError("invalid argument to make_video_annotation")
 
     return VideoAnnotation(
-        first_annotation.annotation_class,
-        frames,
-        keyframes,
-        segments,
-        interpolated,
-        slot_names=slot_names or [],
-        properties=properties,
+        first_annotation.annotation_class, frames, keyframes, segments, interpolated, slot_names=slot_names or []
     )
 
 
-def _maybe_add_bounding_box_data(
-    data: Dict[str, UnknownType], bounding_box: Optional[Dict]
-) -> Dict[str, UnknownType]:
+def _maybe_add_bounding_box_data(data: Dict[str, UnknownType], bounding_box: Optional[Dict]) -> Dict[str, UnknownType]:
     if bounding_box:
         data["bounding_box"] = {
             "x": bounding_box["x"],
@@ -1339,74 +1049,3 @@ def _maybe_add_bounding_box_data(
 ExportParser = Callable[[Iterator[AnnotationFile], Path], None]
 
 ImportParser = Callable[[Path], Union[List[AnnotationFile], AnnotationFile, None]]
-
-
-class MaskTypes:
-    Palette = Dict[str, int]
-    Mode = Literal["index", "grey", "rgb"]
-    TypeOfRender = Literal["raster", "polygon"]
-    CategoryList = List[str]
-    ExceptionList = List[Exception]
-    UndecodedRLE = List[int]
-    DecodedRLE = List[List[int]]
-    ColoursDict = Dict[str, int]
-    RgbColors = List[int]
-    HsvColors = List[Tuple[float, float, float]]
-    RgbColorList = List[RgbColors]
-    RgbPalette = Dict[str, RgbColors]
-
-    RendererReturn = Tuple[ExceptionList, NDArray, CategoryList, ColoursDict]
-
-
-@dataclass
-class AnnotationMask:
-    id: str
-    name: str
-    slot_names: List[str] = field(default_factory=list)
-
-    def validate(self) -> None:
-        if not self.name:
-            raise ValueError("Mask name cannot be empty")
-        if not self.slot_names:
-            raise ValueError("Mask must be associated with at least one slot")
-        if not self.id:
-            raise ValueError("Mask ID cannot be empty")
-
-
-@dataclass
-class RasterLayer:
-    rle: MaskTypes.UndecodedRLE
-    decoded: MaskTypes.DecodedRLE
-    mask_annotation_ids_mapping: Dict[str, int]
-    slot_names: List[str] = field(default_factory=list)
-    total_pixels: int = 0
-
-    def validate(self) -> None:
-        if not self.rle:
-            raise ValueError("RasterLayer rle cannot be empty")
-        if not self.decoded:
-            raise ValueError("RasterLayer decoded cannot be empty")
-        if not self.mask_annotation_ids_mapping:
-            raise ValueError("RasterLayer mask_annotation_ids_mapping cannot be empty")
-        if not self.slot_names:
-            raise ValueError("RasterLayer must be associated with at least one slot")
-        if not self.total_pixels and not self.total_pixels > 0:
-            raise ValueError("RasterLayer total_pixels cannot be empty")
-
-
-@dataclass
-class ManifestItem:
-    frame: int
-    absolute_frame: Optional[int]
-    segment: int
-    visibility: bool
-    timestamp: float
-    visible_frame: Optional[int]
-
-
-@dataclass
-class SegmentManifest:
-    slot: str
-    segment: int
-    total_frames: int
-    items: List[ManifestItem]
